@@ -3,7 +3,7 @@ from django.apps import AppConfig
 
 class DynamicStoragesConfig(AppConfig):
     name = "dynamic_storages"
-    label = "Dynamic Storages"
+    label = "dynamic_storages"
     verbose_name = "Dynamic Storages"
 
     def ready(self):
